@@ -40,10 +40,10 @@ if (opt$usage) {
 Examples:
   tt.r -a                             # test 'all files' from current directory
   tt.r -f testfile.R                  # test the file 'testfile.R'
-  tt.t -d testdir                     # test all files in the directory 'testdir'
+  tt.r -d testdir                     # test all files in the directory 'testdir'
   tt.r -p testpkg                     # test the (installed) package 'testpkg'
   tt.r -n 1 -p testpkg                # test (installed) package 'testpkg' in serial mode
-  tt.r                                # run test_all() iff DESCRIPTION && inst/tinytest/
+  tt.r                                # run test_all() if DESCRIPTION && inst/tinytest/
 
 tt.r is part of littler which brings 'r' to the command-line.
 See http://dirk.eddelbuettel.com/code/littler.html for more information.\n")
